==> 1.1.tar.gz: box-wx/src/lib/lib.js <==
const env = "__ENV__"

import wepy from "wepy";
import { md5 } from "md5";


export const config = {
    'api': (() => {
        let envMap = {
            // 'dev': 'http://test-www-27l.duowan.com/',//本地&测试
            'dev': 'https://www.27l.com/',//本地&测试            
            // 'preview': 'https://wxapi-glance.duowan.com',		//预发布
            'production': 'https://www.27l.com/',	//线上
        }

        return envMap[env]
    })(),
    'plusApi': (() => {
        let envMap = {
            // 'dev': 'http://test-www-27l.duowan.com/',//本地&测试
            'dev': 'https://test-xyxbox.duowan.com/',//本地&测试            
            'preview': 'https://xyxbox.duowan.com/',		//预发布
            'production': 'https://xyxbox.duowan.com/',	//线上
        }

        return envMap[env]
    })(),
    'shop_id': 18,
    "shareImg" : 'http://img.dwstatic.com/www/xyx-box/share-img-1.0.jpg'


}

export const lib = {
    encodePwd(random, pwd) {
        var k1 = md5.sha1(random);
        var k2 = md5.sha1(k1);

        var v = md5.xor(md5.xor(pwd, k2), k1);
        return md5.base64encode(v);
    },

    //任务上报
    reportTask(task_id) { //glancePlayMinute:看视频;share:分享;daySign:每日签到
        let loginData = wx.getStorageSync('loginData')

        if (!task_id && !loginData) return

        let timeStamp = (new Date()).getTime()
        let data = {
            shop_id: config.shop_id,
            task_id: task_id,
            target_id: loginData.lg_uid,
            time: timeStamp
        }
        data = Object.assign(data,loginData)

        let paramData = `shop_id=${config.shop_id}&task_id=${task_id}&target_id=${loginData.lg_uid}&time=${timeStamp}`
        data["sign"] = this.encodePwd(loginData.lg_token, md5.sha1(paramData));

        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.plusApi}/task/report`,
                    data: data
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(true)
                    } else {
                        // wx.showToast({ title: data.msg || '' })

                        resolve(false)
                    }
                })
        })
    }


}

==> 1.2.tar.gz: box-wx/src/lib/lib.js <==
const env = "__ENV__"

import wepy from "wepy";
import { md5 } from "md5";


export const config = {
    'api': (() => {
        let envMap = {
            // 'dev': 'http://test-www-27l.duowan.com/',//本地&测试
            'dev': 'https://www.27l.com/',//本地&测试            
            // 'preview': 'https://wxapi-glance.duowan.com',		//预发布
            'production': 'https://www.27l.com/',	//线上
        }

        return envMap[env]
    })(),
    'plusApi': (() => {
        let envMap = {
            // 'dev': 'http://test-www-27l.duowan.com/',//本地&测试
            'dev': 'https://test-xyxbox.duowan.com/',//本地&测试            
            'preview': 'https://new-xyxbox.duowan.com/',		//预发布
            'production': 'https://xyxbox.duowan.com/',	//线上
        }

        return envMap[env]
    })(),
    'shop_id': 18,
    "shareImg" : 'http://img.dwstatic.com/www/xyx-box/share-img-1.0.jpg'


}

export const lib = {
    encodePwd(random, pwd) {
        var k1 = md5.sha1(random);
        var k2 = md5.sha1(k1);

        var v = md5.xor(md5.xor(pwd, k2), k1);
        return md5.base64encode(v);
    },

    //任务上报
    reportTask(task_id) { //glancePlayMinute:看视频;share:分享;daySign:每日签到
        let loginData = wx.getStorageSync('loginData')

        if (!task_id && !loginData) return

        let timeStamp = (new Date()).getTime()
        let data = {
            shop_id: config.shop_id,
            task_id: task_id,
            target_id: loginData.lg_uid,
            time: timeStamp
        }
        data = Object.assign(data,loginData)

        let paramData = `shop_id=${config.shop_id}&task_id=${task_id}&target_id=${loginData.lg_uid}&time=${timeStamp}`
        data["sign"] = this.encodePwd(loginData.lg_token, md5.sha1(paramData));

        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.plusApi}/task/report`,
                    data: data
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(true)
                    } else {
                        // wx.showToast({ title: data.msg || '' })

                        resolve(false)
                    }
                })
        })
    }


}
